==> connectagram_1.3.2.orig.tar.gz: connectagram-1.3.2/translations/connectagram_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ketting</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Onderbroken</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hekwerk</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;systeem taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart het programma om de taalwijziging door te voeren</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Gemiddeld</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Erg hoog</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Woordlengte:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letter</numerusform>
            <numerusform>%n letters</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringen</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Topscores</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Aantal woorden</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengte</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gefeliciteerd!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Je hebt je topscore verbroken!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Goed gedaan!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Je hebt een nieuwe topscore neergezet!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trappen</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kronkel</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Golf</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Onderbroken</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Betekenissen</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hint</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kiezen…</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Onderbreken</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>Bet&amp;ekenissen</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Top&amp;scores</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>&amp;Donker thema</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmataal…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Kies een spel</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spelnummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Het is niet mogelijk om dit spel te starten.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Een spel waar je woorden moet ordenen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>De betekenissen zijn afkomstig van &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patroon:</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.5.orig.tar.gz: connectagram-1.3.5/translations/connectagram_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ketting</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Onderbroken</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hekwerk</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;systeem taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart het programma om de taalwijziging door te voeren</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Gemiddeld</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Erg hoog</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Woordlengte:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letter</numerusform>
            <numerusform>%n letters</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringen</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Topscores</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Aantal woorden</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengte</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gefeliciteerd!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Je hebt je topscore verbroken!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Goed gedaan!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Je hebt een nieuwe topscore neergezet!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trappen</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kronkel</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Golf</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Onderbroken</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Betekenissen</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hint</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kiezen…</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Onderbreken</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>Bet&amp;ekenissen</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Top&amp;scores</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>&amp;Donker thema</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmataal…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Kies een spel</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spelnummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Het is niet mogelijk om dit spel te starten.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Een spel waar je woorden moet ordenen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>De betekenissen zijn afkomstig van &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patroon:</translation>
    </message>
</context>
</TS>
